#!/usr/bin/python
import os
del os.environ['MKL_NUM_THREADS']
os.environ['CUDA_VISIBLE_DEVICES'] = '0'

import vot
import sys
import time
import cv2
import numpy as np
import collections
import tracker.tracker as tracker

def get_axis_aligned_bbox(region):

    cx = np.mean(region[0, 0::2])
    cy = np.mean(region[0, 1::2])
    x1 = min(region[0, 0::2])
    x2 = max(region[0, 0::2])
    y1 = min(region[0, 1::2])
    y2 = max(region[0, 1::2])
    A1 = np.linalg.norm(region[0, 0:2] - region[0, 2:4]) * np.linalg.norm(region[0, 2:4] - region[0, 4:6])
    A2 = (x2 - x1) * (y2 - y1)
    s = np.sqrt(A1 / A2)
    w = s * (x2 - x1) + 1
    h = s * (y2 - y1) + 1
    x = cx - (w-1)/2
    y = cy - (h-1)/2

    return x, y, w, h


handle = vot.VOT('polygon')
region = handle.region()

x, y, w, h = get_axis_aligned_bbox(np.reshape(np.array(region),[1,-1]))
selection = vot.Rectangle(x, y, w, h)
             
# Process the first frame
image_path = handle.frame()                  # path of first frame
if not image_path:
    sys.exit(0)

image_path = str(image_path)
im = cv2.imread(image_path, cv2.IMREAD_COLOR)

# initilization
tracker_name = 'tracker'
tracker_param = 'default'
run_id = None

tracker = tracker.get_tracker_class(tracker_name, tracker_param)
tracker.initialize(im, selection)

# Tracing:
while True:
    image_path = handle.frame()
    if not image_path:
        break
    image_path = str(image_path)
    im = cv2.imread(image_path, cv2.IMREAD_COLOR)
    region  = tracker.track(im)
    region = vot.Rectangle(region[0],region[1], region[2], region[3])
    handle.report(region)

